Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(194)

Unified Diff: webkit/fileapi/file_system_context.h

Issue 10447083: Rename webkit_blob::FileReader to FileStreamReader. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: merge master branch. Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webkit/chromeos/fileapi/cros_mount_point_provider.cc ('k') | webkit/fileapi/file_system_context.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/fileapi/file_system_context.h
diff --git a/webkit/fileapi/file_system_context.h b/webkit/fileapi/file_system_context.h
index fc10aa7254fa76b90c5401202981f2a4e01ccb76..f8d771de37d083784b80d1c7f9d9afca71c0f225 100644
--- a/webkit/fileapi/file_system_context.h
+++ b/webkit/fileapi/file_system_context.h
@@ -30,7 +30,7 @@ class QuotaManagerProxy;
}
namespace webkit_blob {
-class FileReader;
+class FileStreamReader;
}
namespace fileapi {
@@ -127,13 +127,13 @@ class FILEAPI_EXPORT FileSystemContext
// depending on the filesystem type pointed by the |url|.
FileSystemOperationInterface* CreateFileSystemOperation(const GURL& url);
// Creates new FileReader instance to read a file pointed by the given
// filesystem URL |url| starting from |offset|.
// This method internally cracks the |url|, get an appropriate
// MountPointProvider for the URL and call the provider's CreateFileReader.
// The resolved MountPointProvider could perform further specialization
// depending on the filesystem type pointed by the |url|.
- webkit_blob::FileReader* CreateFileReader(
+ webkit_blob::FileStreamReader* CreateFileStreamReader(
const GURL& url,
int64 offset);
« no previous file with comments | « webkit/chromeos/fileapi/cros_mount_point_provider.cc ('k') | webkit/fileapi/file_system_context.cc » ('j') | no next file with comments »
@@ -127,13 +127,13 @@ class FILEAPI_EXPORT FileSystemContext
// depending on the filesystem type pointed by the |url|.
FileSystemOperationInterface* CreateFileSystemOperation(const GURL& url);
- // Creates new FileReader instance to read a file pointed by the given
+ // Creates new FileStreamReader instance to read a file pointed by the given
// filesystem URL |url| starting from |offset|.
// This method internally cracks the |url|, get an appropriate

Powered by Google App Engine
This is Rietveld 408576698